==> pokerth_0.5+dfsg.orig.tar.gz: pokerth-0.5+dfsg/src/gui/qt/settingsdialog/selectavatardialog/selectavatardialogimpl.h <==
/***************************************************************************
 *   Copyright (C) 2006 by FThauer FHammer   *
 *   f.thauer@web.de   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef SELECTAVATARDIALOGIMPL_H
#define SELECTAVATARDIALOGIMPL_H

#include "ui_selectavatardialog.h"

#include <QtCore>
#include <QtGui>

class ConfigFile;
class selectAvatarDialogImpl;

class selectAvatarDialogImpl: public QDialog, public Ui::selectAvatarDialog {
Q_OBJECT
public:
    selectAvatarDialogImpl(QWidget *parent = 0, ConfigFile *c = 0);
	
	void exec();

	
public slots:
	void toggleGroupBox1(bool);
	void toggleGroupBox2(bool);
	void isAccepted();
	void isRejected();
	
	QString getAvatarLink();
	void setExternalAvatar();

	bool getSettingsCorrect() const	{ return settingsCorrect;}
	

private:
	
	ConfigFile* myConfig;
	bool settingsCorrect;
	QString externalAvatar;
	QString avatarDir;

};

#endif

==> pokerth_0.8.2-1.tar.gz: pokerth-0.8.2/src/gui/qt/settingsdialog/selectavatardialog/selectavatardialogimpl.h <==
/***************************************************************************
 *   Copyright (C) 2006 by FThauer FHammer   *
 *   f.thauer@web.de   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef SELECTAVATARDIALOGIMPL_H
#define SELECTAVATARDIALOGIMPL_H

//--- GUI_800x480 ---
#include "ui_selectavatardialog_800x480.h"
//---
// #include "ui_selectavatardialog.h"
//---

#include <QtCore>
#include <QtGui>

class ConfigFile;
class selectAvatarDialogImpl;

class selectAvatarDialogImpl: public QDialog, public Ui::selectAvatarDialog {
Q_OBJECT
public:
    selectAvatarDialogImpl(QWidget *parent = 0, ConfigFile *c = 0);
	
	void exec();

	
public slots:
	void toggleGroupBox1(bool);
	void toggleGroupBox2(bool);
	void isAccepted();
	void isRejected();
	
	QString getAvatarLink();
	void setExternalAvatar();

	bool getSettingsCorrect() const	{ return settingsCorrect;}

	void refreshAvatarView();
	

private:
	
	ConfigFile* myConfig;

	bool settingsCorrect;
	QString externalAvatar;
	QString avatarDir;
	QString myAppDataPath;
	QStringList miscAvatarList;
	QStringList peopleAvatarList;


};

#endif
